==> regal-0.36.1.tar.gz: regal-0.36.1/internal/lsp/config/find_test.go <==
package config

import (
	"cmp"
	"slices"
	"strings"
	"testing"

	"github.com/open-policy-agent/opa/v1/util/test"
)

func TestFindConfigRoots(t *testing.T) {
	t.Parallel()

	testCases := map[string]struct {
		FS       map[string]string
		Expected []string
	}{
		"no config roots": {
			FS:       map[string]string{},
			Expected: []string{},
		},
		"single config root at root": {
			FS: map[string]string{
				".regal/config.yaml": "",
			},
			Expected: []string{"/"},
		},
		"single config root at root with .regal.yaml": {
			FS: map[string]string{
				".regal.yaml": "",
			},
			Expected: []string{"/"},
		},
		"two config roots, one higher": {
			FS: map[string]string{
				".regal/config.yaml": "",
				"foo/.regal.yaml":    "",
			},
			Expected: []string{
				"/",
				"/foo",
			},
		},
		"two config roots, one higher, not in root dir": {
			FS: map[string]string{
				"foo/.regal.yaml":            "",
				"bar/baz/.regal/config.yaml": "",
			},
			Expected: []string{
				"/bar/baz",
				"/foo",
			},
		},
		"two config roots, equal depth": {
			FS: map[string]string{
				"bar/.regal/config.yaml": "",
				"foo/.regal.yaml":        "",
			},
			Expected: []string{
				"/bar",
				"/foo",
			},
		},
	}

	for testName, testData := range testCases {
		t.Run(testName, func(t *testing.T) {
			t.Parallel()
			test.WithTempFS(testData.FS, func(root string) {
				got, err := FindConfigRoots(root)
				if err != nil {
					t.Fatalf("Unexpected error: %v", err)
				}

				gotTrimmed := make([]string, len(got))

				for i, path := range got {
					trimmed := cmp.Or(strings.TrimPrefix(path, root), "/")
					gotTrimmed[i] = trimmed
				}

				if !slices.Equal(gotTrimmed, testData.Expected) {
					t.Fatalf("Expected %v, got %v", testData.Expected, gotTrimmed)
				}
			})
		})
	}
}

==> regal-0.37.0.tar.gz: regal-0.37.0/internal/lsp/config/find_test.go <==
package config

import (
	"cmp"
	"path/filepath"
	"slices"
	"strings"
	"testing"

	"github.com/open-policy-agent/opa/v1/util/test"
)

func TestFindConfigRoots(t *testing.T) {
	t.Parallel()

	testCases := map[string]struct {
		FS       map[string]string
		Expected []string
	}{
		"no config roots": {
			FS:       map[string]string{},
			Expected: []string{},
		},
		"single config root at root": {
			FS: map[string]string{
				filepath.FromSlash(".regal/config.yaml"): "",
			},
			Expected: []string{filepath.FromSlash("/")},
		},
		"single config root at root with .regal.yaml": {
			FS: map[string]string{
				filepath.FromSlash(".regal.yaml"): "",
			},
			Expected: []string{filepath.FromSlash("/")},
		},
		"two config roots, one higher": {
			FS: map[string]string{
				filepath.FromSlash(".regal/config.yaml"): "",
				filepath.FromSlash("foo/.regal.yaml"):    "",
			},
			Expected: []string{
				filepath.FromSlash("/"),
				filepath.FromSlash("/foo"),
			},
		},
		"two config roots, one higher, not in root dir": {
			FS: map[string]string{
				filepath.FromSlash("foo/.regal.yaml"):            "",
				filepath.FromSlash("bar/baz/.regal/config.yaml"): "",
			},
			Expected: []string{
				filepath.FromSlash("/bar/baz"),
				filepath.FromSlash("/foo"),
			},
		},
		"two config roots, equal depth": {
			FS: map[string]string{
				filepath.FromSlash("bar/.regal/config.yaml"): "",
				filepath.FromSlash("foo/.regal.yaml"):        "",
			},
			Expected: []string{
				filepath.FromSlash("/bar"),
				filepath.FromSlash("/foo"),
			},
		},
	}

	for testName, testData := range testCases {
		t.Run(testName, func(t *testing.T) {
			t.Parallel()
			test.WithTempFS(testData.FS, func(root string) {
				got, err := FindConfigRoots(root)
				if err != nil {
					t.Fatalf("Unexpected error: %v", err)
				}

				gotTrimmed := make([]string, len(got))

				for i, path := range got {
					trimmed := cmp.Or(strings.TrimPrefix(path, root), filepath.FromSlash("/"))
					gotTrimmed[i] = trimmed
				}

				if !slices.Equal(gotTrimmed, testData.Expected) {
					t.Fatalf("Expected %v, got %v", testData.Expected, gotTrimmed)
				}
			})
		})
	}
}
